@@ -21,8 +21,8 @@
 
 /********************** crop here for forms.h **********************/
 
-/*
- * $Id: Basic.h,v 1.0 2002/05/08 05:16:30 zhao Release $
+/**
+ * \file Basic.h
  *
  *  Basic definitions and limits.
  *  Window system independent prototypes
@@ -343,7 +343,15 @@ typedef enum
     FL_TRPLCLICK,		/* triple click            */
     FL_ATTRIB,			/* attribute change        */
     FL_KEYRELEASE,
-    FL_PS			/* dump a form into EPS    */
+    FL_PS,			/* dump a form into EPS    */
+    FL_MOVEORIGIN,		/* dragging the form across the screen
+				   changes its absolute x,y coords. Objects
+				   that themselves contain forms should
+				   ensure that they are up to date. */
+    FL_RESIZED			/* The object has been resized by scale_form
+				   Tell it that this has happened so that
+				   it can resize any FL_FORMs that it
+				   contains. */
 }
 FL_EVENTS;
 
@@ -402,19 +410,6 @@ enum
 #define FL_PUP_TOGGLE    FL_PUP_BOX
 #define FL_PUP_INACTIVE  FL_PUP_GREY
 
-/* read rgb.txt file */
-FL_EXPORT int fl_init_RGBdatabase(
-		const char *f
-		);
-
-FL_EXPORT int fl_lookup_RGBcolor(
-		const char *req_name,
-		int *r,
-		int *g,
-		int *b
-		);
-
-
 /* popup and menu entries */
 typedef int (*FL_PUP_CB) (int);	/* call back prototype  */
 typedef struct
@@ -604,11 +599,11 @@ FL_EXPORT FL_OBJECT *FL_EVENT;
 
 /* form visibility state: form->visible */
 enum {
-  FL_BEING_HIDDEN = -1, 
-  FL_HIDDEN = 0, 
+  FL_BEING_HIDDEN = -1,
+  FL_HIDDEN = 0,
   FL_INVISIBLE = FL_HIDDEN,
   FL_VISIBLE = 1
-}; 
+};
 
 typedef struct forms_
 {
