@@ -20,8 +20,8 @@
  */
 
 
-/*
- * $Id: scrollbar.c,v 1.0 2002/05/08 05:16:30 zhao Release $
+/**
+ * \file scrollbar.c
  *.
  *  This file is part of the XForms library package.
  *  Copyright (c) 1996-2002  T.C. Zhao
@@ -31,8 +31,12 @@
  *  Scrollbar
  */
 
-#include "forms.h"
-#include "pscrollbar.h"
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+#include "include/forms.h"
+#include "flinternal.h"
+#include "private/pscrollbar.h"
 
 #define SPEC FL_SCROLLBAR_SPEC
 
