@@ -20,14 +20,18 @@
  */
 
 
-/*
- * $Id$
+/**
+ * \file vn_pair.c
  *
  * Name value pair stuff
  */
 
 
-#include "forms.h"
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+#include "include/forms.h"
+#include "flinternal.h"
 #include "ulib.h"
 #include <stdlib.h>
 
